import files_com_mcp
from files_sdk.api_client import ApiClient

_original_request_headers = ApiClient.request_headers


def patched_request_headers(self, api_key, session_id, language):
    headers = _original_request_headers(self, api_key, session_id, language)
    headers["User-Agent"] = "Files.com Python MCP SDK v{version}".format(
        version=files_com_mcp.__version__
    )

    return headers


ApiClient.request_headers = patched_request_headers



from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def delete_file(
    context: Context,
    path: Annotated[
        str | None, Field(description="Path to operate on.", default=None)
    ],
) -> str:
    """Delete File/Folder

    Args:
        path: Path to operate on.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if path is None:
            return "Missing required parameter: path"
        params["path"] = path

        retval = files_sdk.file.delete(path, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["path", "destination"]
        )
        return f"File Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def find_file(
    context: Context,
    path: Annotated[
        str | None, Field(description="Path to operate on.", default=None)
    ],
) -> str:
    """Find File/Folder by Path

    Args:
        path: Path to operate on.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if path is None:
            return "Missing required parameter: path"
        params["path"] = path

        retval = files_sdk.file.find(path, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["path", "destination"]
        )
        return f"File Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def copy_file(
    context: Context,
    path: Annotated[
        str | None, Field(description="Path to operate on.", default=None)
    ],
    destination: Annotated[
        str | None, Field(description="Copy destination path.", default=None)
    ],
) -> str:
    """Copy File/Folder

    Args:
        path: Path to operate on.
        destination: Copy destination path.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if path is None:
            return "Missing required parameter: path"
        params["path"] = path
        if destination is None:
            return "Missing required parameter: destination"
        params["destination"] = destination

        retval = files_sdk.file.copy(path, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["path", "destination"]
        )
        return f"File Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def move_file(
    context: Context,
    path: Annotated[
        str | None, Field(description="Path to operate on.", default=None)
    ],
    destination: Annotated[
        str | None, Field(description="Move destination path.", default=None)
    ],
) -> str:
    """Move File/Folder

    Args:
        path: Path to operate on.
        destination: Move destination path.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if path is None:
            return "Missing required parameter: path"
        params["path"] = path
        if destination is None:
            return "Missing required parameter: destination"
        params["destination"] = destination

        retval = files_sdk.file.move(path, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["path", "destination"]
        )
        return f"File Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(name="Delete_File", description="Delete File/Folder")
    async def delete_file_tool(
        context: Context,
        path: Annotated[
            str | None, Field(description="Path to operate on.", default=None)
        ],
    ) -> str:
        return await delete_file(context, path)

    @mcp.tool(name="Find_File", description="Find File/Folder by Path")
    async def find_file_tool(
        context: Context,
        path: Annotated[
            str | None, Field(description="Path to operate on.", default=None)
        ],
    ) -> str:
        return await find_file(context, path)

    @mcp.tool(name="Copy_File", description="Copy File/Folder")
    async def copy_file_tool(
        context: Context,
        path: Annotated[
            str | None, Field(description="Path to operate on.", default=None)
        ],
        destination: Annotated[
            str | None,
            Field(description="Copy destination path.", default=None),
        ],
    ) -> str:
        return await copy_file(context, path, destination)

    @mcp.tool(name="Move_File", description="Move File/Folder")
    async def move_file_tool(
        context: Context,
        path: Annotated[
            str | None, Field(description="Path to operate on.", default=None)
        ],
        destination: Annotated[
            str | None,
            Field(description="Move destination path.", default=None),
        ],
    ) -> str:
        return await move_file(context, path, destination)



from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_permission(
    context: Context,
    path: Annotated[
        str | None,
        Field(
            description="Permission path.  If provided, will scope all permissions(including upward) to this path.",
            default=None,
        ),
    ],
    group_id: Annotated[str | None, Field(description="", default=None)],
    user_id: Annotated[str | None, Field(description="", default=None)],
) -> str:
    """List Permissions

    Args:
        path: Permission path.  If provided, will scope all permissions(including upward) to this path.
        group_id:
        user_id:
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if path is not None:
            params["path"] = path
        if group_id is not None:
            params["group_id"] = group_id
        if user_id is not None:
            params["user_id"] = user_id

        retval = files_sdk.permission.list(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No permissions found."

        markdown_list = object_list_to_markdown_table(
            retval, ["path", "group_id", "user_id", "permission", "id"]
        )
        return f"Permission Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def create_permission(
    context: Context,
    path: Annotated[
        str | None, Field(description="Folder path", default=None)
    ],
    group_id: Annotated[
        int | None,
        Field(
            description="Group ID. Provide `group_name` or `group_id`",
            default=None,
        ),
    ],
    permission: Annotated[
        str | None,
        Field(
            description="Permission type.  Can be `admin`, `full`, `readonly`, `writeonly`, `list`, or `history`",
            default=None,
        ),
    ],
    user_id: Annotated[
        int | None,
        Field(
            description="User ID.  Provide `username` or `user_id`",
            default=None,
        ),
    ],
) -> str:
    """Create Permission

    Args:
        path: Folder path
        group_id: Group ID. Provide `group_name` or `group_id`
        permission: Permission type.  Can be `admin`, `full`, `readonly`, `writeonly`, `list`, or `history`
        user_id: User ID.  Provide `username` or `user_id`
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if path is None:
            return "Missing required parameter: path"
        params["path"] = path
        if group_id is not None:
            params["group_id"] = group_id
        if permission is not None:
            params["permission"] = permission
        if user_id is not None:
            params["user_id"] = user_id

        retval = files_sdk.permission.create(params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["path", "group_id", "user_id", "permission", "id"]
        )
        return f"Permission Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def delete_permission(
    context: Context,
    id: Annotated[
        int | None, Field(description="Permission ID.", default=None)
    ],
) -> str:
    """Delete Permission

    Args:
        id: Permission ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.permission.delete(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["path", "group_id", "user_id", "permission", "id"]
        )
        return f"Permission Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(name="List_Permission", description="List Permissions")
    async def list_permission_tool(
        context: Context,
        path: Annotated[
            str | None,
            Field(
                description="Permission path.  If provided, will scope all permissions(including upward) to this path.",
                default=None,
            ),
        ],
        group_id: Annotated[str | None, Field(description="", default=None)],
        user_id: Annotated[str | None, Field(description="", default=None)],
    ) -> str:
        return await list_permission(context, path, group_id, user_id)

    @mcp.tool(name="Create_Permission", description="Create Permission")
    async def create_permission_tool(
        context: Context,
        path: Annotated[
            str | None, Field(description="Folder path", default=None)
        ],
        group_id: Annotated[
            int | None,
            Field(
                description="Group ID. Provide `group_name` or `group_id`",
                default=None,
            ),
        ],
        permission: Annotated[
            str | None,
            Field(
                description="Permission type.  Can be `admin`, `full`, `readonly`, `writeonly`, `list`, or `history`",
                default=None,
            ),
        ],
        user_id: Annotated[
            int | None,
            Field(
                description="User ID.  Provide `username` or `user_id`",
                default=None,
            ),
        ],
    ) -> str:
        return await create_permission(
            context, path, group_id, permission, user_id
        )

    @mcp.tool(name="Delete_Permission", description="Delete Permission")
    async def delete_permission_tool(
        context: Context,
        id: Annotated[
            int | None, Field(description="Permission ID.", default=None)
        ],
    ) -> str:
        return await delete_permission(context, id)



from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_user(context: Context) -> str:
    """List Users"""

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}

        retval = files_sdk.user.list(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No users found."

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "username",
                "email",
                "group_ids",
                "password",
                "authentication_method",
                "name",
                "company",
                "notes",
                "require_password_change",
                "user_root",
                "user_home",
            ],
        )
        return f"User Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def find_user(
    context: Context,
    id: Annotated[int | None, Field(description="User ID.", default=None)],
) -> str:
    """Show User

    Args:
        id: User ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.user.find(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "username",
                "email",
                "group_ids",
                "password",
                "authentication_method",
                "name",
                "company",
                "notes",
                "require_password_change",
                "user_root",
                "user_home",
            ],
        )
        return f"User Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def create_user(
    context: Context,
    username: Annotated[
        str | None, Field(description="User's username", default=None)
    ],
    email: Annotated[
        str | None, Field(description="User's email.", default=None)
    ],
    group_ids: Annotated[
        str | None,
        Field(
            description="A list of group ids to associate this user with.  Comma delimited.",
            default=None,
        ),
    ],
    password: Annotated[
        str | None, Field(description="User password.", default=None)
    ],
    authentication_method: Annotated[
        str | None,
        Field(description="How is this user authenticated?", default=None),
    ],
    name: Annotated[
        str | None, Field(description="User's full name", default=None)
    ],
    company: Annotated[
        str | None, Field(description="User's company", default=None)
    ],
    notes: Annotated[
        str | None,
        Field(description="Any internal notes on the user", default=None),
    ],
    require_password_change: Annotated[
        bool | None,
        Field(
            description="Is a password change required upon next user login?",
            default=None,
        ),
    ],
    user_root: Annotated[
        str | None,
        Field(
            description="Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set).  Note that this is not used for API, Desktop, or Web interface.",
            default=None,
        ),
    ],
    user_home: Annotated[
        str | None,
        Field(
            description="Home folder for FTP/SFTP.  Note that this is not used for API, Desktop, or Web interface.",
            default=None,
        ),
    ],
) -> str:
    """Create User

    Args:
        username: User's username
        email: User's email.
        group_ids: A list of group ids to associate this user with.  Comma delimited.
        password: User password.
        authentication_method: How is this user authenticated?
        name: User's full name
        company: User's company
        notes: Any internal notes on the user
        require_password_change: Is a password change required upon next user login?
        user_root: Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set).  Note that this is not used for API, Desktop, or Web interface.
        user_home: Home folder for FTP/SFTP.  Note that this is not used for API, Desktop, or Web interface.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if username is None:
            return "Missing required parameter: username"
        params["username"] = username
        if email is not None:
            params["email"] = email
        if group_ids is not None:
            params["group_ids"] = group_ids
        if password is not None:
            params["password"] = password
        if authentication_method is not None:
            params["authentication_method"] = authentication_method
        if name is not None:
            params["name"] = name
        if company is not None:
            params["company"] = company
        if notes is not None:
            params["notes"] = notes
        if require_password_change is not None:
            params["require_password_change"] = require_password_change
        if user_root is not None:
            params["user_root"] = user_root
        if user_home is not None:
            params["user_home"] = user_home

        # Smart Default(s)
        params["dav_permission"] = True

        # Smart Default(s)
        params["ftp_permission"] = True

        # Smart Default(s)
        params["restapi_permission"] = True

        # Smart Default(s)
        params["sftp_permission"] = True

        retval = files_sdk.user.create(params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "username",
                "email",
                "group_ids",
                "password",
                "authentication_method",
                "name",
                "company",
                "notes",
                "require_password_change",
                "user_root",
                "user_home",
            ],
        )
        return f"User Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def update_user(
    context: Context,
    id: Annotated[int | None, Field(description="User ID.", default=None)],
    email: Annotated[
        str | None, Field(description="User's email.", default=None)
    ],
    group_ids: Annotated[
        str | None,
        Field(
            description="A list of group ids to associate this user with.  Comma delimited.",
            default=None,
        ),
    ],
    password: Annotated[
        str | None, Field(description="User password.", default=None)
    ],
    authentication_method: Annotated[
        str | None,
        Field(description="How is this user authenticated?", default=None),
    ],
    name: Annotated[
        str | None, Field(description="User's full name", default=None)
    ],
    company: Annotated[
        str | None, Field(description="User's company", default=None)
    ],
    notes: Annotated[
        str | None,
        Field(description="Any internal notes on the user", default=None),
    ],
    require_password_change: Annotated[
        bool | None,
        Field(
            description="Is a password change required upon next user login?",
            default=None,
        ),
    ],
    user_root: Annotated[
        str | None,
        Field(
            description="Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set).  Note that this is not used for API, Desktop, or Web interface.",
            default=None,
        ),
    ],
    user_home: Annotated[
        str | None,
        Field(
            description="Home folder for FTP/SFTP.  Note that this is not used for API, Desktop, or Web interface.",
            default=None,
        ),
    ],
    username: Annotated[
        str | None, Field(description="User's username", default=None)
    ],
) -> str:
    """Update User

    Args:
        id: User ID.
        email: User's email.
        group_ids: A list of group ids to associate this user with.  Comma delimited.
        password: User password.
        authentication_method: How is this user authenticated?
        name: User's full name
        company: User's company
        notes: Any internal notes on the user
        require_password_change: Is a password change required upon next user login?
        user_root: Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set).  Note that this is not used for API, Desktop, or Web interface.
        user_home: Home folder for FTP/SFTP.  Note that this is not used for API, Desktop, or Web interface.
        username: User's username
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id
        if email is not None:
            params["email"] = email
        if group_ids is not None:
            params["group_ids"] = group_ids
        if password is not None:
            params["password"] = password
        if authentication_method is not None:
            params["authentication_method"] = authentication_method
        if name is not None:
            params["name"] = name
        if company is not None:
            params["company"] = company
        if notes is not None:
            params["notes"] = notes
        if require_password_change is not None:
            params["require_password_change"] = require_password_change
        if user_root is not None:
            params["user_root"] = user_root
        if user_home is not None:
            params["user_home"] = user_home
        if username is not None:
            params["username"] = username

        # Smart Default(s)
        params["dav_permission"] = True

        # Smart Default(s)
        params["ftp_permission"] = True

        # Smart Default(s)
        params["restapi_permission"] = True

        # Smart Default(s)
        params["sftp_permission"] = True

        retval = files_sdk.user.update(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "username",
                "email",
                "group_ids",
                "password",
                "authentication_method",
                "name",
                "company",
                "notes",
                "require_password_change",
                "user_root",
                "user_home",
            ],
        )
        return f"User Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def delete_user(
    context: Context,
    id: Annotated[int | None, Field(description="User ID.", default=None)],
) -> str:
    """Delete User

    Args:
        id: User ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.user.delete(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "username",
                "email",
                "group_ids",
                "password",
                "authentication_method",
                "name",
                "company",
                "notes",
                "require_password_change",
                "user_root",
                "user_home",
            ],
        )
        return f"User Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(name="List_User", description="List Users")
    async def list_user_tool(context: Context) -> str:
        return await list_user(context)

    @mcp.tool(name="Find_User", description="Show User")
    async def find_user_tool(
        context: Context,
        id: Annotated[int | None, Field(description="User ID.", default=None)],
    ) -> str:
        return await find_user(context, id)

    @mcp.tool(name="Create_User", description="Create User")
    async def create_user_tool(
        context: Context,
        username: Annotated[
            str | None, Field(description="User's username", default=None)
        ],
        email: Annotated[
            str | None, Field(description="User's email.", default=None)
        ],
        group_ids: Annotated[
            str | None,
            Field(
                description="A list of group ids to associate this user with.  Comma delimited.",
                default=None,
            ),
        ],
        password: Annotated[
            str | None, Field(description="User password.", default=None)
        ],
        authentication_method: Annotated[
            str | None,
            Field(description="How is this user authenticated?", default=None),
        ],
        name: Annotated[
            str | None, Field(description="User's full name", default=None)
        ],
        company: Annotated[
            str | None, Field(description="User's company", default=None)
        ],
        notes: Annotated[
            str | None,
            Field(description="Any internal notes on the user", default=None),
        ],
        require_password_change: Annotated[
            bool | None,
            Field(
                description="Is a password change required upon next user login?",
                default=None,
            ),
        ],
        user_root: Annotated[
            str | None,
            Field(
                description="Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set).  Note that this is not used for API, Desktop, or Web interface.",
                default=None,
            ),
        ],
        user_home: Annotated[
            str | None,
            Field(
                description="Home folder for FTP/SFTP.  Note that this is not used for API, Desktop, or Web interface.",
                default=None,
            ),
        ],
    ) -> str:
        return await create_user(
            context,
            username,
            email,
            group_ids,
            password,
            authentication_method,
            name,
            company,
            notes,
            require_password_change,
            user_root,
            user_home,
        )

    @mcp.tool(name="Update_User", description="Update User")
    async def update_user_tool(
        context: Context,
        id: Annotated[int | None, Field(description="User ID.", default=None)],
        email: Annotated[
            str | None, Field(description="User's email.", default=None)
        ],
        group_ids: Annotated[
            str | None,
            Field(
                description="A list of group ids to associate this user with.  Comma delimited.",
                default=None,
            ),
        ],
        password: Annotated[
            str | None, Field(description="User password.", default=None)
        ],
        authentication_method: Annotated[
            str | None,
            Field(description="How is this user authenticated?", default=None),
        ],
        name: Annotated[
            str | None, Field(description="User's full name", default=None)
        ],
        company: Annotated[
            str | None, Field(description="User's company", default=None)
        ],
        notes: Annotated[
            str | None,
            Field(description="Any internal notes on the user", default=None),
        ],
        require_password_change: Annotated[
            bool | None,
            Field(
                description="Is a password change required upon next user login?",
                default=None,
            ),
        ],
        user_root: Annotated[
            str | None,
            Field(
                description="Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set).  Note that this is not used for API, Desktop, or Web interface.",
                default=None,
            ),
        ],
        user_home: Annotated[
            str | None,
            Field(
                description="Home folder for FTP/SFTP.  Note that this is not used for API, Desktop, or Web interface.",
                default=None,
            ),
        ],
        username: Annotated[
            str | None, Field(description="User's username", default=None)
        ],
    ) -> str:
        return await update_user(
            context,
            id,
            email,
            group_ids,
            password,
            authentication_method,
            name,
            company,
            notes,
            require_password_change,
            user_root,
            user_home,
            username,
        )

    @mcp.tool(name="Delete_User", description="Delete User")
    async def delete_user_tool(
        context: Context,
        id: Annotated[int | None, Field(description="User ID.", default=None)],
    ) -> str:
        return await delete_user(context, id)



from typing import List, Any


def object_list_to_markdown_table(
    items: List[Any], attributes: List[str]
) -> str:
    """
    Convert a list of objects into a Markdown table using selected attributes.

    :param items: List of objects (same type) to convert.
    :param attributes: List of attribute names (strings) to include as columns.
    :return: A string containing the Markdown-formatted table.
    """
    if not items:
        return "*(no data)*"

    # Header row
    table_lines = ["| " + " | ".join(attributes) + " |"]

    # Separator row
    table_lines.append("| " + " | ".join("---" for _ in attributes) + " |")

    # Data rows
    for obj in items:
        values = [str(getattr(obj, attr, "")) for attr in attributes]
        table_lines.append("| " + " | ".join(values) + " |")

    return "\n".join(table_lines)



from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_bundle(context: Context) -> str:
    """List Bundles"""

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}

        retval = files_sdk.bundle.list(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No bundles found."

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "paths",
                "password",
                "expires_at",
                "max_uses",
                "description",
                "note",
                "require_registration",
            ],
        )
        return f"Bundle Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def find_bundle(
    context: Context,
    id: Annotated[int | None, Field(description="Bundle ID.", default=None)],
) -> str:
    """Show Bundle (also called Share Link)

    Args:
        id: Bundle ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.bundle.find(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "paths",
                "password",
                "expires_at",
                "max_uses",
                "description",
                "note",
                "require_registration",
            ],
        )
        return f"Bundle Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def create_bundle(
    context: Context,
    paths: Annotated[
        list | None,
        Field(
            description="A list of paths to include in this bundle.",
            default=None,
        ),
    ],
    password: Annotated[
        str | None,
        Field(description="Password for this bundle.", default=None),
    ],
    expires_at: Annotated[
        str | None,
        Field(description="Bundle expiration date/time", default=None),
    ],
    max_uses: Annotated[
        int | None,
        Field(
            description="Maximum number of times bundle can be accessed",
            default=None,
        ),
    ],
    description: Annotated[
        str | None, Field(description="Public description", default=None)
    ],
    note: Annotated[
        str | None, Field(description="Bundle internal note", default=None)
    ],
    require_registration: Annotated[
        bool | None,
        Field(
            description="Show a registration page that captures the downloader's name and email address?",
            default=None,
        ),
    ],
) -> str:
    """Create Bundle (also called Share Link)

    Args:
        paths: A list of paths to include in this bundle.
        password: Password for this bundle.
        expires_at: Bundle expiration date/time
        max_uses: Maximum number of times bundle can be accessed
        description: Public description
        note: Bundle internal note
        require_registration: Show a registration page that captures the downloader's name and email address?
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if paths is None:
            return "Missing required parameter: paths"
        params["paths"] = paths
        if password is not None:
            params["password"] = password
        if expires_at is not None:
            params["expires_at"] = expires_at
        if max_uses is not None:
            params["max_uses"] = max_uses
        if description is not None:
            params["description"] = description
        if note is not None:
            params["note"] = note
        if require_registration is not None:
            params["require_registration"] = require_registration

        # Smart Default(s)
        params["permissions"] = "read"

        retval = files_sdk.bundle.create(params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "paths",
                "password",
                "expires_at",
                "max_uses",
                "description",
                "note",
                "require_registration",
            ],
        )
        return f"Bundle Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def update_bundle(
    context: Context,
    id: Annotated[int | None, Field(description="Bundle ID.", default=None)],
    expires_at: Annotated[
        str | None,
        Field(description="Bundle expiration date/time", default=None),
    ],
) -> str:
    """Update Bundle (also called Share Link)

    Args:
        id: Bundle ID.
        expires_at: Bundle expiration date/time
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id
        if expires_at is not None:
            params["expires_at"] = expires_at

        retval = files_sdk.bundle.update(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "paths",
                "password",
                "expires_at",
                "max_uses",
                "description",
                "note",
                "require_registration",
            ],
        )
        return f"Bundle Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def delete_bundle(
    context: Context,
    id: Annotated[int | None, Field(description="Bundle ID.", default=None)],
) -> str:
    """Delete Bundle (also called Share Link)

    Args:
        id: Bundle ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.bundle.delete(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "paths",
                "password",
                "expires_at",
                "max_uses",
                "description",
                "note",
                "require_registration",
            ],
        )
        return f"Bundle Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(
        name="List_Bundle",
        description="List Bundles (also called Share Links)",
    )
    async def list_bundle_tool(context: Context) -> str:
        return await list_bundle(context)

    @mcp.tool(
        name="Find_Bundle", description="Show Bundle (also called Share Link)"
    )
    async def find_bundle_tool(
        context: Context,
        id: Annotated[
            int | None, Field(description="Bundle ID.", default=None)
        ],
    ) -> str:
        return await find_bundle(context, id)

    @mcp.tool(
        name="Create_Bundle",
        description="Create Bundle (also called Share Link)",
    )
    async def create_bundle_tool(
        context: Context,
        paths: Annotated[
            list | None,
            Field(
                description="A list of paths to include in this bundle.",
                default=None,
            ),
        ],
        password: Annotated[
            str | None,
            Field(description="Password for this bundle.", default=None),
        ],
        expires_at: Annotated[
            str | None,
            Field(description="Bundle expiration date/time", default=None),
        ],
        max_uses: Annotated[
            int | None,
            Field(
                description="Maximum number of times bundle can be accessed",
                default=None,
            ),
        ],
        description: Annotated[
            str | None, Field(description="Public description", default=None)
        ],
        note: Annotated[
            str | None, Field(description="Bundle internal note", default=None)
        ],
        require_registration: Annotated[
            bool | None,
            Field(
                description="Show a registration page that captures the downloader's name and email address?",
                default=None,
            ),
        ],
    ) -> str:
        return await create_bundle(
            context,
            paths,
            password,
            expires_at,
            max_uses,
            description,
            note,
            require_registration,
        )

    @mcp.tool(
        name="Update_Bundle",
        description="Update Bundle (also called Share Link)",
    )
    async def update_bundle_tool(
        context: Context,
        id: Annotated[
            int | None, Field(description="Bundle ID.", default=None)
        ],
        expires_at: Annotated[
            str | None,
            Field(description="Bundle expiration date/time", default=None),
        ],
    ) -> str:
        return await update_bundle(context, id, expires_at)

    @mcp.tool(
        name="Delete_Bundle",
        description="Delete Bundle (also called Share Link)",
    )
    async def delete_bundle_tool(
        context: Context,
        id: Annotated[
            int | None, Field(description="Bundle ID.", default=None)
        ],
    ) -> str:
        return await delete_bundle(context, id)



from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_automation(context: Context) -> str:
    """List Automations"""

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}

        retval = files_sdk.automation.list(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No automations found."

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "always_overwrite_size_matching_files",
                "automation",
                "deleted",
                "description",
                "destination_replace_from",
                "destination_replace_to",
                "destinations",
                "disabled",
                "exclude_pattern",
                "import_urls",
                "flatten_destination_structure",
                "group_ids",
                "ignore_locked_folders",
                "interval",
                "last_modified_at",
                "legacy_folder_matching",
                "name",
                "overwrite_files",
                "path",
                "path_time_zone",
                "recurring_day",
                "retry_on_failure_interval_in_minutes",
                "retry_on_failure_number_of_attempts",
                "schedule",
                "human_readable_schedule",
                "schedule_days_of_week",
                "schedule_times_of_day",
                "schedule_time_zone",
                "source",
                "sync_ids",
                "trigger_actions",
                "trigger",
                "user_id",
                "user_ids",
                "value",
                "webhook_url",
            ],
        )
        return f"Automation Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def find_automation(
    context: Context,
    id: Annotated[
        int | None, Field(description="Automation ID.", default=None)
    ],
) -> str:
    """Show Automation

    Args:
        id: Automation ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.automation.find(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "always_overwrite_size_matching_files",
                "automation",
                "deleted",
                "description",
                "destination_replace_from",
                "destination_replace_to",
                "destinations",
                "disabled",
                "exclude_pattern",
                "import_urls",
                "flatten_destination_structure",
                "group_ids",
                "ignore_locked_folders",
                "interval",
                "last_modified_at",
                "legacy_folder_matching",
                "name",
                "overwrite_files",
                "path",
                "path_time_zone",
                "recurring_day",
                "retry_on_failure_interval_in_minutes",
                "retry_on_failure_number_of_attempts",
                "schedule",
                "human_readable_schedule",
                "schedule_days_of_week",
                "schedule_times_of_day",
                "schedule_time_zone",
                "source",
                "sync_ids",
                "trigger_actions",
                "trigger",
                "user_id",
                "user_ids",
                "value",
                "webhook_url",
            ],
        )
        return f"Automation Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(name="List_Automation", description="List Automations")
    async def list_automation_tool(context: Context) -> str:
        return await list_automation(context)

    @mcp.tool(name="Find_Automation", description="Show Automation")
    async def find_automation_tool(
        context: Context,
        id: Annotated[
            int | None, Field(description="Automation ID.", default=None)
        ],
    ) -> str:
        return await find_automation(context, id)



async def hello_world() -> str:
    """Files.com MCP Debugging Hello World function."""
    return "Hello World"


def register_tools(mcp):
    @mcp.tool(
        name="Hello_World",
        description="Files.com MCP Debugging Hello World function.",
    )
    async def hello_world_tool() -> str:
        return await hello_world()
